.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Light Curve Fitting Documentation
=================================

This package contains tools to fit analytical models to multiband light curves of astronomical transients.
If you use this code in a publication, please **cite the original papers** whose models you used, as well as my Zenodo repository.

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.2639463.svg
   :target: https://doi.org/10.5281/zenodo.2639463


.. toctree::
   :maxdepth: 2

   installation
   usage
   api
   release-history
